@@ -1,8 +1,10 @@
 __name__ = "ytb-up"
-__version__ = "0.1.13"
+__version__ = "0.1.14"
 
 from .exceptions import *
 from .constants import *
 from .logging import Log
-from .upload import Upload
+from .youtube import YoutubeUpload
+from .douyin import DouyinUpload
+
 from .login import *
