@@ -10,7 +10,7 @@ def domain_to_url(domain: str) -> str:
         domain = "www" + domain
     return "http://" + domain
 
-def login_using_cookie_file(self, cookie_file: str,page):
+async def format_cookie_file(cookie_file: str):
     """Restore auth cookies from a file. Does not guarantee that the user is logged in afterwards.
     Visits the domains specified in the cookies to set them, the previous page is not restored."""
     domain_cookies: Dict[str, List[object]] = {}
@@ -19,21 +19,19 @@ def login_using_cookie_file(self, cookie_file: str,page):
         cookies: List = json.load(file)
         # Sort cookies by domain, because we need to visit to domain to add cookies
         for cookie in cookies:
+            if cookie['sameSite']=='no_restriction' or cookie['sameSite'].lower()=='no_restriction':
+                cookie.update(sameSite='None')            
             try:
                 domain_cookies[cookie["domain"]].append(cookie)
             except KeyError:
                 domain_cookies[cookie["domain"]] = [cookie]
     # print(str(domain_cookies).replace(",", ",\n"))
 
-
-    for domain, cookies in domain_cookies.items():
-        # while True:
-        page.goto(domain_to_url(domain + "/robots.txt"))
-        for cookie in cookies:
-            cookie.pop("sameSite", None)  # Attribute should be available in Selenium >4
-            cookie.pop("storeId", None)  # Firefox container attribute
-        print('add cookies')
-    self.context.add_cookies(cookies)
+            # cookie.pop("sameSite", None)  # Attribute should be available in Selenium >4
+            # cookie.pop("storeId", None)  # Firefox container attribute
+    print('add cookies',domain_cookies[cookie["domain"]])
+    # await self.context.add_cookies(cookies)
+    return domain_cookies[cookie["domain"]]
 def confirm_logged_in(page) -> bool:
     """ Confirm that the user is logged in. The browser needs to be navigated to a YouTube page. """
     try:
@@ -44,6 +42,14 @@ def confirm_logged_in(page) -> bool:
         return True
     except TimeoutError:
         return False
+def confirm_logged_in_douyin(page) -> bool:
+    try:
+
+        page.locator('.avatar--1lU_a')
+        return True
+    except:
+        return False
+
 def confirm_logged_in(page) -> bool:
     """ Confirm that the user is logged in. The browser needs to be navigated to a YouTube page. """
     try:
